@@ -4,7 +4,7 @@ use 5.008008;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use POE qw( Wheel::Run  Filter::Reference  Filter::Line);
 use Carp;
@@ -56,7 +56,8 @@ sub spawn {
 
 sub _start {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
-
+    $self->{session_id} = $_[SESSION]->ID();
+    
     if  ( $self->{alias} ) {
         $kernel->alias_set( $self->{alias} );
     }
@@ -138,7 +139,7 @@ sub _shutdown {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
     $kernel->alarm_remove_all;
     $kernel->alias_remove( $_ ) for $kernel->alias_list;
-    $kernel->refcount_decrement( $self => __PACKAGE__ )
+    $kernel->refcount_decrement( $self->{session_id} => __PACKAGE__ )
         unless $self->{alias};
 
     $self->{shutdown} = 1;
